pyxmpp2.transport

Package pyxmpp2 :: Module transport |
[hide private]

# Module transport

XMPP transport.

This module provides the abstract base class for XMPP transports (mechanisms used to send and receive XMPP content, not to be confused with protocol gateways sometimes also called 'transports') and the standard TCP transport.

Classes | [hide private]
| WriteJob Base class for objects put to the TCPTransport write queue.
| ContinueConnect Object to signal (via the write queue) a pending connect request.
| StartTLS StartTLS request for the TCPTransport write queue.
| TLSHandshake Object to signal (via the write queue) a pending TLS handshake.
| WriteData Data queued for write.
| TCPTransport XMPP over TCP with optional TLS.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.transport")`